==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/cs/CsCustomTransientAttribute.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

namespace com.db4o.test.cs
{

	public class CsCustomTransientAttribute
	{

        [CustomTransient]
        String myTransient;

        String myPersistent;

        public void configure(){
            Db4o.configure().markTransient("com.db4o.test.cs.CustomTransient");
        }

        public void storeOne(){
            myTransient = "trans";
            myPersistent = "pers";
        }

        public void testOne(){
            Tester.ensure(myTransient == null);
            Tester.ensure(myPersistent.Equals("pers"));
        }
	}

    public class CustomTransient : Attribute {
        public CustomTransient() {
        }
    }

}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/cs/CsCustomTransientAttribute.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;

namespace com.db4o.test.cs
{

	public class CsCustomTransientAttribute
	{

        [CustomTransient]
        String myTransient;

        String myPersistent;

        public void Configure(){
            Db4o.Configure().MarkTransient("com.db4o.test.cs.CustomTransient");
        }

        public void StoreOne(){
            myTransient = "trans";
            myPersistent = "pers";
        }

        public void TestOne(){
            Tester.Ensure(myTransient == null);
            Tester.Ensure(myPersistent.Equals("pers"));
        }
	}

    public class CustomTransient : Attribute {
        public CustomTransient() {
        }
    }

}
